/* Main Styles */
.wrapper h1,
.wrapper h2,
.wrapper h3 {
  color: #55575d;
}
/* top bar */
.top-bar {
  color: #fff;
  background-color: #8d0e59;
}
.top-bar p {
  display: inline-block;
  font-size: 16px;
  margin-right: 5px; 
}
.login-box {
  padding-top: 4px;
  padding-left: 20px;
}
.login-box p span {
  text-decoration: underline;
}
/* menu */
.header-wrapper {
  padding: 30px 0 20px 20px;
  width: 100%;
  max-width: 1024px;
  float: left;
}
.menu-heading {
  float: left;
  width: 130px;
  height: 30px;
}
.menu {
  float: right;
  margin-right: 10px;
}
.menu li {
  list-style-type: none; 
  float: left;
  margin-left: 5px;
}
.menu li a {
  padding: 10px;
  color: #fff;
  background-color: #55575d;
  border-radius: 2px;
}
.menu li a:hover {
  background-color: #8d0e59;
}
.menu li .selected {
  background-color: #8d0e59
}
@media all and (max-width: 700px) { 
  .menu-heading {
    float: none;
    text-align: center;
    width: 100%;
    display: block;
    margin-bottom: 20px;
  }
  .menu {
    float: none;
    padding: 0;
  }
  .menu li {
    margin-bottom: 20px;
  }
}
/* main content */
.content-wrapper {
  margin: 20px;
  max-width: 1024px;
  clear: both;
}
/* login */
.form ul {
  margin-bottom: 10px;
  padding: 0; 
}
.form ul li {
  list-style-type: none; 
}
.errorlist {
  color: red;
}
/* board */
.board-wrapper {
  width: 50%; 
  float: left;
}
.board_here,
.status_here {
  margin: 10px 0;
}
.status_here {
  width: 50%; 
  float: left;
}
/* table styles */
.win {
  background-color: #CDFAC8;
}
.loss {
  background-color: #FCE3E3;
}
.draw {
  background-color: #FFFEBF;
}
/* upload */
#id_code {
  display: block;
}
