{% extends "main.html" %}
{% load i18n %}

{% block home_selected %}selected{% endblock %}

{% block title %}{% trans "Ultimate Tic Tac Toe Hello" %}{% endblock %}

{% block content %}

<h1>Who’s the Ultimate Gamesmaster?</h1>

After hours of hard work, it’s time for some serious fun. This is the challenge
that separates the men from the boys. Think you can cut it against your fellow
nerds to win the title of Ultimate Gamesmaster? <a href="{% url "rules" %}">
Read the rules</a> and get ready to rumble.

<h1>What’s the tournament?</h1>

Ever played tic-tac-toe? Pretty simple, right? Not this one. This tic-tac-toe
is bigger, tougher, and has a lot more at stake. Exclusively for BOI2014
Olympiad, this board is an extended 9x9 grid.  Your challenge is to program
solutions, in real time, that win you the game. If you’re good, you’ll go all
the way to the finals to compete for the title of Ultimate Gamesmaster.

<h1>What can I win?</h1>

You mean, besides the prestige?? This ultimate challenge is about kudos:
respect, fame, fortune, envy…

<h4>Except for these things, there’s also some cool prizes up for grabs:</h4>

<div style="margin-left: 20px">

Your first victory comes against an example program. This program plays by the
rules, but doesn’t think much. Source code is available.<br/>

<b>What you win:</b> a high-quality Spil Games summer cap.<br/>

At the end of the Olympiad, your win-loss record will be analyzed against those
of your opponents. The top 5 players will be crowned Ultimate Gamesmaster.<br/>

<b>What you win:</b> a Limited Edition Holy-Cow t-shirt. This designates you as
a programming Guru, a warrior on the path to code enlightenment.

</div>

<h1>When does it run?</h1>
The contest opens at 10:00 CEST on 2014-04-26 and closes at 16:00 on
2014-04-29. Winners will be awarded at the closing event, held at 19:00 on
2014-04-29.

<h1>How do I get access?</h1>
Your username and password are the same as of your practice session. If you
can't login, or you have questions, it's best to grab me (Motiejus Jakštys) and
we'll resolve it together. My picture is in the Technical Committee's list in
the program you received on the first day. Alternatively, email me at: <a
href="mailto:motiejus.jakstys@gmail.com">motiejus.jakstys@gmail.com</a>.

{% endblock %}
