{% extends "main.html" %}
{% load i18n %}

{% block upload_selected %}selected{% endblock %}

{% block title %}{% trans "Upload program" %}{% endblock %}

{% block content %}
  <h3>{% trans "Upload program" %}</h3>
  <form method="POST" action="{{ request.get_full_path }}">
    {% csrf_token %}
    {{ form.as_p }}
    <input class="btn btn-sm btn-default" type="submit" value="{% trans "Submit" %}" />
  </form>
{% endblock %}
