{% extends "main.html" %}
{% load i18n %}

{% block who_got_capped_selected %}selected{% endblock %}

{% block title %}{% trans "Who got capped?" %}{% endblock %}

{% block content %}
<h2>{% trans "Who got capped?" %}</h2>

These people have successfully qualified for the Gamesmaster Challenge - catch
them in their caps:

<table class="table">
  <thead>
    <tr>
      <th>User</th>
      <th>When</th>
      <th>Notes</th>
    </tr>
  </thead>
  {% for cap in caps %}
  <tr>
    <td>
       <a href="{% url "tictactoe.contest.views.entries" uid=cap.user.id %}">
         {{ cap.user }}
       </a>
     </td>

    <td>
      {{ cap.when|date:"Y-m-d H:i:s" }}
    </td>

    <td>
      {{ cap.notes }}
    </td>
  </tr>
  {% endfor %}
</table>

{% endblock %}
