{% load i18n %}
{% load staticfiles %}

<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}">
<head>

{% block head %}
    <title>{% block title %}Tic Tac Toe Challenge{% endblock %}</title>
{% endblock %}
{% block end_head %}{% endblock %}
<meta charset="utf8">

<link href="{% static "css/main.css" %}" rel="stylesheet">
<link href="{% static "bootstrap/css/bootstrap.min.css" %}" media="screen" rel="stylesheet">
</head>
<body>
<script type="text/javascript"/>
window.tictactoe = {};
window.tictactoe.static_url = '{{ STATIC_URL }}';
</script>
{% block body %}{% endblock %}
{% block end_body %}{% endblock %}
</body>
</html>
