{% extends "main.html" %}
{% load i18n %}

{% block ranking_selected %}selected{% endblock %}

{% block title %}{% trans "Entry list" %}{% endblock %}

{% block content %}

<table class="table" border="1" style="border-collapse: collapse" cellpadding="5px" cellspacing="1">
  <thead>
    <tr>
      <th>{% trans "User" %}</th>
      <th>{% trans "Entry Size" %}</th>
      <th>{% trans "Uploaded" %}</th>
      <th>{% trans "Wins" %}</th>
      <th>{% trans "Draws" %}</th>
      <th>{% trans "Losses" %}</th>
    </tr>
  </thead>
  {% for latestentry in latestentries %}
  <tr>
    <td>
      <a href="{% url "tictactoe.contest.views.entries" uid=entry.user.id %}">
      {{ latestentry.user.get_full_name }} ({{ entry.user.username }})
      </a>
    </td>
    <td>{{ latestentry.entry.codesize|filesizeformat }}</td>
    <td>
      <a href="{{ latestentry.entry.get_absolute_url }}">
        {{ latestentry.entry.uploaded|date:"Y-m-d H:i:s" }}
      </a>
    </td>
    <td>{{ latestentry.results.0 }}</td>
    <td>{{ latestentry.results.1 }}</td>
    <td>{{ latestentry.results.2 }}</td>
  </tr>
  {% endfor %}
</table>

{% endblock content %}
