{% extends "main.html" %}
{% load i18n %}

{% block title %}{% trans "Login" %}{% endblock %}

{% block content %}
  <h3>{% trans "Login" %}</h3>
  <form class="form" method="POST" action="{{ request.get_full_path }}">
    {% csrf_token %}
    <input type="hidden" name="next" value="{{ next }}" />
    <ul>{{ form.as_ul }}</ul>
    <input class="btn btn-sm btn-default" type="submit" value="{% trans "Submit" %}" />
  </form>
{% endblock %}
